apply_cohort_filter: Apply OHDSI cohort filtering to CDM table references.

View source: R/extract.R

apply_cohort_filterR Documentation

Apply OHDSI cohort filtering to CDM table references.

Description

Modifies db$cdm table references to filter by a standard OHDSI cohort table. Filters person, observation_period, death, and event tables to cohort members and their cohort windows.

Usage

apply_cohort_filter(db, cohort_id, cohort_schema = NULL)

Arguments

db

Connection list (from syrona_connect).

cohort_id

Integer cohort_definition_id to filter by.

cohort_schema

Schema containing the cohort table (NULL = default).

Value

Modified db list with filtered CDM table references.


syrona documentation built on Sept. 5, 2026, 1:06 a.m.