extract_death_counts: Extract death counts by year x sex x age group (ACHILLES-504...

View source: R/extract.R

extract_death_countsR Documentation

Extract death counts by year x sex x age group (ACHILLES-504 pattern).

Description

Extract death counts by year x sex x age group (ACHILLES-504 pattern).

Usage

extract_death_counts(cdm, denom_df)

Arguments

cdm

CDM reference object.

denom_df

Pre-computed denominator tibble.

Value

tibble with columns: year, sex, age_group, death_count, denominator, mortality_rate


syrona documentation built on Sept. 5, 2026, 1:06 a.m.