| syrona-package | R Documentation |
Derives stratified prevalence tables from the condition, procedure, and drug records in OMOP CDM databases, computes log2 prevalence ratios between paired datasets, and synthesizes them via random-effects meta-analysis at multiple aggregation levels (year, age group, sex).
Maintainer: Maarja Pajusalu maarja.pajusalu@ut.ee
Authors:
Maarja Pajusalu maarja.pajusalu@ut.ee
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.