| insert_cohort | R Documentation |
Uploads a data frame to the database via omopgenerics::insertTable
and marks it as a cohort table with omopgenerics::newCohortTable.
Use this when cohort membership has already been computed locally
(e.g. from a CSV or programmatic cohort definition).
insert_cohort(cdm, cohort_df, name = "cohort")
cdm |
A CDM reference (from |
cohort_df |
Data frame with columns: |
name |
Name for the cohort table in the database (default |
Requires that the CDM connection was created with a writeSchema.
Updated CDM reference with the cohort table attached.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.