| load_syrona_theme | R Documentation |
Makes color constants, thresholds, and other design tokens available as variables. Used by the Shiny dashboard's global.R.
load_syrona_theme(envir = parent.frame())
envir |
Environment to load into (default: caller's environment). |
No return value, called for its side effect of assigning the design
tokens as variables in envir.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.